==> dyte_core-0.1.0%2B3.tar.gz: example/lib/models/states/participant_event_states.dart <==
import 'package:dyte_core/dyte_core.dart';
import 'package:freezed_annotation/freezed_annotation.dart';

part 'participant_event_states.freezed.dart';

@freezed
class ParticipantEventStates with _$ParticipantEventStates {
  const factory ParticipantEventStates.initial() = _ParticipantEventStates;
  const factory ParticipantEventStates.audioUpdate({
    required bool audioEnabled,
    required DyteMeetingParticipant participant,
  }) = _ParticipantEventStatesAudioUpdate;
  const factory ParticipantEventStates.onActiveSpeakerChanged(
          DyteMeetingParticipant participant) =
      _ParticipantEventStateOnActiveSpeakerChanged;
  const factory ParticipantEventStates.onNoActiveSpeaker() =
      _ParticipantEventStatesOnNoActiveSpeaker;
  const factory ParticipantEventStates.onParticipantJoin(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantJoin;
  const factory ParticipantEventStates.onParticipantLeave(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantLeave;
  const factory ParticipantEventStates.onParticipantPinned(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantPinned;
  const factory ParticipantEventStates.onParticipantUnpinned() =
      _ParticipantEventStatesOnParticipantUnpinned;
  const factory ParticipantEventStates.onParticipantUpdated(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantUpdated;
  const factory ParticipantEventStates.onScreenSharesUpdated() =
      _ParticipantEventStatesOnScreenSharesUpdated;
  const factory ParticipantEventStates.onParticipantsUpdated({
    required DyteRoomParticipants participants,
    required bool isNextPagePossible,
    required bool isPreviousPagePossible,
  }) = _ParticipantEventStatesOnParticipantsUpdated;
  const factory ParticipantEventStates.onUpdate(
      DyteRoomParticipants participants) = _ParticipantEventStatesOnUpdate;
  const factory ParticipantEventStates.videoUpdate(
          {required bool videoEnabled,
          required DyteMeetingParticipant participant}) =
      _ParticipantEventStatesVideoUpdate;
}

==> dyte_core-0.1.1%2B3.tar.gz: example/lib/models/states/participant_event_states.dart <==
import 'package:dyte_core/dyte_core.dart';
import 'package:freezed_annotation/freezed_annotation.dart';

part 'participant_event_states.freezed.dart';

@freezed
class ParticipantEventStates with _$ParticipantEventStates {
  const factory ParticipantEventStates.initial() = _ParticipantEventStates;

  const factory ParticipantEventStates.onAudioUpdate({
    required bool audioEnabled,
    required DyteMeetingParticipant participant,
  }) = _ParticipantEventStatesAudioUpdate;

  const factory ParticipantEventStates.onActiveSpeakerChanged(
          DyteMeetingParticipant participant) =
      _ParticipantEventStateOnActiveSpeakerChanged;

  const factory ParticipantEventStates.onNoActiveSpeaker() =
      _ParticipantEventStatesOnNoActiveSpeaker;

  const factory ParticipantEventStates.onParticipantJoin(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantJoin;

  const factory ParticipantEventStates.onParticipantLeave(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantLeave;

  const factory ParticipantEventStates.onParticipantPinned(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnParticipantPinned;

  const factory ParticipantEventStates.onParticipantUnpinned() =
      _ParticipantEventStatesOnParticipantUnpinned;

  const factory ParticipantEventStates.onScreenSharesUpdated() =
      _ParticipantEventStatesOnScreenSharesUpdated;

  const factory ParticipantEventStates.onUpdate(
      DyteRoomParticipants participants) = _ParticipantEventStatesOnUpdate;

  const factory ParticipantEventStates.onVideoUpdate(
          {required bool videoEnabled,
          required DyteMeetingParticipant participant}) =
      _ParticipantEventStatesVideoUpdate;

  const factory ParticipantEventStates.onActiveParticipantsChanged(
          {required List<DyteMeetingParticipant> activeParticipants}) =
      _OnActiveParticipantsChanged;

  const factory ParticipantEventStates.onWaitListParticipantAccepted(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnWaitListParticipantAccepted;

  const factory ParticipantEventStates.onWaitListParticipantClosed(
          DyteMeetingParticipant participant) =
      _ParticipantEventStateOnWaitListParticipantClosed;

  const factory ParticipantEventStates.onWaitListParticipantJoined(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnWaitListParticipantJoined;

  const factory ParticipantEventStates.onWaitListParticipantRejected(
          DyteMeetingParticipant participant) =
      _ParticipantEventStatesOnWaitListParticipantRejected;
}
